@@ -504,6 +504,9 @@ class EntityIterator(object):
             self._graph._transaction_rollback(txn)
             raise GrapheekDataException(repr(e))
 
+    def all(self):
+        return list(self)
+
     def collect(self, *aliases):
         result = []
         for entity in self:  # Iterating updates the context ...
