@@ -53,7 +53,7 @@ def build_filter_funcs(**filters):
     return filter_funcs
 
 
-def entity_match(filter_funcs, data):
+def entity_match(filter_funcs, data, internals=None):
     if data == UNDEFINED:  # pragma : no cover
         # This could happen because of concurrent modifications (my different process or different threads)
         # This won't normally occur when load testing with greenlets -> thus no cover
@@ -63,7 +63,10 @@ def entity_match(filter_funcs, data):
         try:
             field_value = data[field]
         except KeyError:
-            field_value = None
+            try:
+                field_value = internals[field]
+            except (KeyError, TypeError):
+                field_value = None
         if field_value is None and clause != 'isnull':
             return False
         try:
@@ -82,13 +85,13 @@ def filter_entities(graph, kind, iterator, filter_funcs, on_item=False):
         if on_item:
             for entity_id in iterator:
                 data = graph._get(None, kind + '/' + str(entity_id) + '/' + DATA_SUFFIX)
-                match = entity_match(filter_funcs, data)
+                match = entity_match(filter_funcs, data, {'_id': entity_id})
                 if match:
                     yield graph._item_from_id(kind, entity_id)
         else:
             for entity_id in iterator:
                 data = graph._get(None, kind + '/' + str(entity_id) + '/' + DATA_SUFFIX)
-                match = entity_match(filter_funcs, data)
+                match = entity_match(filter_funcs, data, {'_id': entity_id})
                 if match:
                     yield entity_id
     else:
