@@ -1,7 +1,12 @@
 #!/usr/bin/env
 # -*- coding: utf-8 -*-
 
-from itertools import izip_longest, product
+try:  # pragma : no cover
+    from itertools import izip_longest as zip_longest
+except ImportError:  # pragma : no cover
+    from itertools import zip_longest
+
+from itertools import product
 from collections import defaultdict
 
 import json
@@ -76,9 +81,9 @@ class ExactIndex(BaseIndex):
         # Getting data for all entity_id in chunk of <CHUNK_SIZE>
         filter_length = self._filter_length
         filter_funcs = self._filter_funcs
-        for entity_ids in izip_longest(*([id_iterator] * CHUNK_SIZE), fillvalue=FORBIDDEN_KEY):
+        for entity_ids in zip_longest(*([id_iterator] * CHUNK_SIZE), fillvalue=FORBIDDEN_KEY):
             entity_datas = self._graph._bulk_get(txn, [build_key(kind, entity_id, DATA_SUFFIX) for entity_id in entity_ids if entity_id != FORBIDDEN_KEY])
-            for entity_key, data in entity_datas.items():
+            for entity_key, data in list(entity_datas.items()):
                 if filter_length and not entity_match(filter_funcs, data):
                     continue
                 entity_id = int(entity_key.replace(kind + '/', '').replace('/' + DATA_SUFFIX, ''))  # not very clean :(
@@ -87,13 +92,13 @@ class ExactIndex(BaseIndex):
                 values_to_id[normalize_value(lst)].append(entity_id)
         # This dic will contain the mapping entity id index key -> value chunk id
         entity_dict = {}
-        for value, entity_ids in values_to_id.iteritems():
+        for value, entity_ids in values_to_id.items():
             lst = []
             value_count_key = build_key(self._prefix, COUNT_SUFFIX, value)
             value_count = self._graph._get(txn, value_count_key)
             if value_count == UNDEFINED:
                 value_count = 0
-            chunk_idx = value_count / CHUNK_SIZE
+            chunk_idx = value_count // CHUNK_SIZE
             for entity_id in entity_ids:
                 value_count += 1
                 entity_dict[build_key(self._prefix, entity_id)] = build_key(chunk_idx, value)  # Need to keep an info of relation between entity and the chunk id that contains it
@@ -120,7 +125,7 @@ class ExactIndex(BaseIndex):
         # Incrementing entity count for value
         self._graph._set(txn, value_count_key, value_count + 1)
         #  1st adding entity_id to good chunk :
-        chunk_idx = value_count / CHUNK_SIZE
+        chunk_idx = value_count // CHUNK_SIZE
         chunk_key = build_key(self._prefix, chunk_idx, value)
         self._graph._append_to_lst(txn, chunk_key, entity_id)
         # Say that entity_id is in a chunk
@@ -151,7 +156,7 @@ class ExactIndex(BaseIndex):
             return False
         common_filters = {}
         if self._filter_length:
-            for key, value in self._filters.items():
+            for key, value in list(self._filters.items()):
                 out_value = exact_filters[key]
                 if value == out_value or (isinstance(out_value, list) and value in out_value):
                     common_filters[key] = value
@@ -187,7 +192,7 @@ class ExactIndex(BaseIndex):
             value_count_key = build_key(self._prefix, COUNT_SUFFIX, value)
             value_count_current = self._graph._get(txn, value_count_key)
             if value_count_current != UNDEFINED:
-                for chunk_idx in range(0, 1 + int(value_count_current) / CHUNK_SIZE):
+                for chunk_idx in range(0, 1 + int(value_count_current) // CHUNK_SIZE):
                     entity_ids_key = build_key(self._prefix, chunk_idx, value)
                     entity_ids = self._graph._get_lst(txn, entity_ids_key)
                     if entity_ids != UNDEFINED:
