@@ -201,6 +201,9 @@ class ProxyEntityIterator(ProxyIteratorCommon):
     def update(self, **updates):
         self._raw('update', **updates)
 
+    def all(self):
+        return self._raw('all')
+
     def collect(self, *aliases):
         return self._raw('collect', *aliases)
 
