@@ -13,12 +13,15 @@ The final call will :
 - effectively be run by the server
 - potentially have side effects on the graph
 
-As you can see, in the call method, there's no need to pass 'g' and 'ctx' as those 2 variables are hold by the EntityIterator
+As you can see, in the call method, there's no need to pass '_g' and '_ctxs' as those 2 variables are hold by the EntityIterator
 The 'call' method will be in charge of looking for the right function and calling function passing g/ctx/ and other parameters
 """
 
 
-def add_edge(_g, _ctx, _ref1, _ref2, **data):
-    node1 = _ctx[_ref1]
-    node2 = _ctx[_ref2]
-    _g.add_edge(node1, node2, **data)
+def add_edge(_g, _ctxs, _ref1, _ref2, **data):
+    edge_defns = []
+    for _ctx in _ctxs:
+        node1 = _ctx[_ref1]
+        node2 = _ctx[_ref2]
+        edge_defns.append((node1, node2, data))
+    _g.bulk_add_edge(edge_defns, silent=True)
